@@ -14,7 +14,6 @@
  */
 
 #include "environ.h"
-
 #include "connection.h"
 #include "dlg_specific.h"
 #include "statement.h"
@@ -156,7 +155,7 @@ ER_ReturnError(PG_ErrorInfo *error,
 	/*
 	 *	Even though an application specifies a larger error message
 	 *	buffer, the driver manager changes it silently.
-	 *	Therefore we divide the error message into ... 
+	 *	Therefore we divide the error message into ...
 	 */
 	if (error->recsize < 0)
 	{
@@ -174,19 +173,19 @@ ER_ReturnError(PG_ErrorInfo *error,
 	}
 	stapos = (RecNumber - 1) * error->recsize;
 	if (stapos > msglen)
-		return SQL_NO_DATA_FOUND; 
+		return SQL_NO_DATA_FOUND;
 	pcblen = wrtlen = msglen - stapos;
 	if (pcblen > error->recsize)
 		pcblen = error->recsize;
 	if (0 == cbErrorMsgMax)
-		wrtlen = 0; 
+		wrtlen = 0;
 	else if (wrtlen >= cbErrorMsgMax)
 	{
 		if (partial_ok)
 			wrtlen = cbErrorMsgMax - 1;
 		else if (cbErrorMsgMax <= error->recsize)
 			wrtlen = 0;
-		else 
+		else
 			wrtlen = error->recsize;
 	}
 	if (wrtlen > pcblen)
@@ -263,7 +262,7 @@ PGAPI_StmtError(	HSTMT hstmt,
 	/*
 	 *	Even though an application specifies a larger error message
 	 *	buffer, the driver manager changes it silently.
-	 *	Therefore we divide the error message into ... 
+	 *	Therefore we divide the error message into ...
 	 */
 	if (stmt->error_recsize < 0)
 	{
@@ -281,19 +280,19 @@ PGAPI_StmtError(	HSTMT hstmt,
 	}
 	stapos = (RecNumber - 1) * stmt->error_recsize;
 	if (stapos > msglen)
-		return SQL_NO_DATA_FOUND; 
+		return SQL_NO_DATA_FOUND;
 	pcblen = wrtlen = msglen - stapos;
 	if (pcblen > stmt->error_recsize)
 		pcblen = stmt->error_recsize;
 	if (0 == cbErrorMsgMax)
-		wrtlen = 0; 
+		wrtlen = 0;
 	else if (wrtlen >= cbErrorMsgMax)
 	{
 		if (partial_ok)
 			wrtlen = cbErrorMsgMax - 1;
 		else if (cbErrorMsgMax <= stmt->error_recsize)
 			wrtlen = 0;
-		else 
+		else
 			wrtlen = stmt->error_recsize;
 	}
 	if (wrtlen > pcblen)
@@ -353,8 +352,8 @@ PGAPI_StmtError(	HSTMT hstmt,
 				/* having no stmtstring is also a malloc problem */
 				break;
 			case STMT_ERROR_TAKEN_FROM_BACKEND:
-				pg_sqlstate_set(env, szSqlState, "HY000", "S1000");
-				/* general error */
+				pg_sqlstate_set(env, szSqlState, SC_get_sqlstate(stmt), "S1000");
+				/* Use the ODBC 3 sqlstate reported by the backend. */
 				break;
 			case STMT_INTERNAL_ERROR:
 				pg_sqlstate_set(env, szSqlState, "HY000", "S1000");
@@ -608,7 +607,7 @@ PGAPI_EnvError(		HENV henv,
 	if (!EN_get_error(env, &status, &msg) || NULL == msg)
 	{
 			mylog("EN_get_error: status = %d, msg = #%s#\n", status, msg);
-		
+
 		if (NULL != szSqlState)
 			pg_sqlstate_set(env, szSqlState, "00000", "00000");
 		if (NULL != pcbErrorMsg)
@@ -724,11 +723,16 @@ EN_Destructor(EnvironmentClass *self)
 	 */
 
 	/* Free any connections belonging to this environment */
+	ENTER_CONNS_CS;
 	for (lf = 0; lf < MAX_CONNECTIONS; lf++)
 	{
 		if (conns[lf] && conns[lf]->henv == self)
+		{
 			rv = rv && CC_Destructor(conns[lf]);
+			conns[lf] = NULL;
+		}
 	}
+	LEAVE_CONNS_CS;
 	DELETE_ENV_CS(self);
 	free(self);
 
