@@ -7,7 +7,6 @@
  */
 
 #include "psqlodbc.h"
-
 #include "connection.h"
 #include "pgapifunc.h"
 
@@ -147,10 +146,7 @@ PGAPI_GetInfo30(HDBC hdbc, UWORD fInfoType, PTR rgbInfoValue,
 			break;
 		case SQL_CATALOG_NAME:
 			len = 0;
-			if (PG_VERSION_LE(conn, 7.2))
-				p = "N";
-			else
-				p = "Y"; /* hopefully */
+            p = "N";
 			break;
 		case SQL_COLLATION_SEQ:
 			len = 0;
@@ -183,11 +179,11 @@ PGAPI_GetInfo30(HDBC hdbc, UWORD fInfoType, PTR rgbInfoValue,
 			len = 4;
 			value = SQL_CT_CREATE_TABLE | SQL_CT_COLUMN_CONSTRAINT
 				| SQL_CT_COLUMN_DEFAULT;
-			if (PG_VERSION_GE(conn, 6.5)) 
-				value |= SQL_CT_GLOBAL_TEMPORARY; 
-			if (PG_VERSION_GE(conn, 7.0)) 
+			if (PG_VERSION_GE(conn, 6.5))
+				value |= SQL_CT_GLOBAL_TEMPORARY;
+			if (PG_VERSION_GE(conn, 7.0))
 				value |= SQL_CT_TABLE_CONSTRAINT
-					| SQL_CT_CONSTRAINT_NAME_DEFINITION 
+					| SQL_CT_CONSTRAINT_NAME_DEFINITION
 					| SQL_CT_CONSTRAINT_INITIALLY_DEFERRED
 					| SQL_CT_CONSTRAINT_INITIALLY_IMMEDIATE
 					| SQL_CT_CONSTRAINT_DEFERRABLE;
@@ -299,7 +295,7 @@ PGAPI_GetInfo30(HDBC hdbc, UWORD fInfoType, PTR rgbInfoValue,
 			break;
 		case SQL_SQL92_NUMERIC_VALUE_FUNCTIONS:
 			len = 4;
-			value = SQL_SNVF_BIT_LENGTH | SQL_SNVF_CHAR_LENGTH 
+			value = SQL_SNVF_BIT_LENGTH | SQL_SNVF_CHAR_LENGTH
 				| SQL_SNVF_CHARACTER_LENGTH | SQL_SNVF_EXTRACT
 				| SQL_SNVF_OCTET_LENGTH | SQL_SNVF_POSITION;
 			break;
@@ -318,7 +314,7 @@ PGAPI_GetInfo30(HDBC hdbc, UWORD fInfoType, PTR rgbInfoValue,
 					| SQL_SRJO_FULL_OUTER_JOIN | SQL_SRJO_INNER_JOIN
 					| SQL_SRJO_INTERSECT_JOIN | SQL_SRJO_LEFT_OUTER_JOIN
 					| SQL_SRJO_NATURAL_JOIN | SQL_SRJO_RIGHT_OUTER_JOIN
-					| SQL_SRJO_UNION_JOIN; 
+					| SQL_SRJO_UNION_JOIN;
 			break;
 		case SQL_SQL92_REVOKE:
 			len = 4;
@@ -364,7 +360,7 @@ PGAPI_GetInfo30(HDBC hdbc, UWORD fInfoType, PTR rgbInfoValue,
 	{
 		/* char/binary data */
 		len = strlen(p);
-
+#ifdef  UNICODE_SUPPORT
                 /* Note that at this point we don't know if we've been called just
                  * to get the length of the output. If it's unicode, then we better
                  * adjust to bytes now, so we don't return a buffer size that's too
@@ -372,13 +368,14 @@ PGAPI_GetInfo30(HDBC hdbc, UWORD fInfoType, PTR rgbInfoValue,
                  */
                 if (conn->unicode)
                     len = len * WCLEN;
-                
+#endif
 		if (rgbInfoValue)
 		{
-
+#ifdef  UNICODE_SUPPORT
 			if (conn->unicode)
 				len = utf8_to_ucs2(p, len, (SQLWCHAR *) rgbInfoValue, cbInfoValueMax / 2);
 			else
+#endif
 				strncpy_null((char *) rgbInfoValue, p, (size_t) cbInfoValueMax);
 
 			if (len >= cbInfoValueMax)
@@ -404,7 +401,7 @@ PGAPI_GetInfo30(HDBC hdbc, UWORD fInfoType, PTR rgbInfoValue,
 		*pcbInfoValue = len;
 
 	mylog("%s: p='%s', len=%d, value=%d, cbMax=%d\n", func, p ? p : "<NULL>", len, value, cbInfoValueMax);
-	
+
 	return result;
 }
 
