@@ -28,7 +28,8 @@ pg_CS CS_Table[] =
 	{ "EUC_KR",	EUC_KR },
 	{ "EUC_TW",	EUC_TW },
 	{ "JOHAB", JOHAB },
-	{ "UNICODE",	UTF8 },
+	{ "UNICODE",	PG_UNICODE },
+	{ "UTF8",	UTF8 },		/* Corresponding from Version 8.1 */
 	{ "MULE_INTERNAL",MULE_INTERNAL },
 	{ "LATIN1",	LATIN1 },
 	{ "LATIN2",	LATIN2 },
@@ -42,10 +43,13 @@ pg_CS CS_Table[] =
 	{ "LATIN10", LATIN10 },
 	{ "WIN1256", WIN1256 },
 	{ "TCVN", TCVN },
+	{ "WIN1258", WIN1258 },		/* Corresponding from Version 8.1 */
 	{ "WIN874", WIN874 },
 	{ "KOI8",	KOI8R },
-	{ "WIN",	WIN1251 },
-	{ "ALT",	ALT },
+	{ "WIN",	WIN },
+	{ "WIN1251",	WIN1251 },	/* Corresponding from Version 8.1 */
+	{ "ALT",	ALT  },
+	{ "WIN866",	WIN866  },	/* Corresponding from Version 8.1 */
 	{ "ISO_8859_5", ISO_8859_5 },
 	{ "ISO_8859_6", ISO_8859_6 },
 	{ "ISO_8859_7", ISO_8859_7 },
@@ -194,11 +198,11 @@ pg_CS_stat(int stat,unsigned int character,int characterset_code)
 /* EUC_JP Support */
 		case EUC_JP:
 			{
-				if (stat < 3 && 
+				if (stat < 3 &&
 					character == 0x8f)	/* JIS X 0212 */
 					stat = 3;
 				else
-				if (stat != 2 && 
+				if (stat != 2 &&
 					(character == 0x8e ||
 					character > 0xa0))	/* Half Katakana HighByte & Kanji HighByte */
 					stat = 2;
@@ -280,7 +284,7 @@ pg_mbschr(int csc, const UCHAR *string, unsigned int character)
 	int			mb_st = 0;
 	const UCHAR *s, *rs = NULL;
 
-	for(s = string; *s ; s++) 
+	for(s = string; *s ; s++)
 	{
 		mb_st = pg_CS_stat(mb_st, (UCHAR) *s, csc);
 		if (mb_st == 0 && (*s == character))
@@ -376,7 +380,64 @@ CC_lookup_characterset(ConnectionClass *self)
 		encstr = CC_lookup_cs_new(self);
 	if (self->client_encoding)
 		free(self->client_encoding);
+#ifndef UNICODE_SUPPORT 	 
+#ifdef  WIN32 	 
+	else 	 
+	{ 	 
+		const char *wenc = NULL; 	 
+		switch (GetACP()) 	 
+		{ 	 
+			case 932: 	 
+				wenc = "SJIS"; 	 
+				break; 	 
+			case 936: 	 
+				if (!encstr || PG_VERSION_GT(self, 7.2)) 	 
+					wenc = "GBK"; 	 
+				break; 	 
+			case 949: 	 
+				if (!encstr || (PG_VERSION_GT(self, 7.2) && stricmp(encstr, "EUC_KR"))) 	 
+					wenc = "UHC"; 	 
+				break; 	 
+			case 950: 	 
+				wenc = "BIG5"; 	 
+				break; 	 
+			case 1250: 	 
+				wenc = "WIN1250"; 	 
+				break; 	 
+			case 1251: 	 
+				if (PG_VERSION_GE(self, 8.1)) 	 
+					wenc = "WIN1251"; 	 
+				else
+					wenc = "WIN"; 	 
+				break; 	 
+			case 1252: 	 
+				if (PG_VERSION_GE(self, 7.2)) 	 
+					wenc = "latin9"; 	 
+				else 	 
+					wenc = "latin1"; 	 
+				break; 	 
+		} 	 
+		if (wenc && (!encstr || stricmp(encstr, wenc))) 	 
+		{ 	 
+			QResultClass    *res; 	 
+			char            query[64]; 	 
+			int             errnum = CC_get_errornumber(self); 	 
 
+			sprintf(query, "set client_encoding to '%s'", wenc); 	 
+			res = CC_send_query(self, query, NULL, CLEAR_RESULT_ON_ABORT); 	 
+			CC_set_errornumber(self, errnum); 	 
+			if (res) 	 
+			{ 	 
+				self->client_encoding = strdup(wenc); 	 
+				self->ccsc = pg_CS_code(self->client_encoding); 	 
+				QR_Destructor(res); 	 
+				free(encstr); 	 
+				return; 	 
+			} 	 
+		} 	 
+	} 	 
+#endif /* WIN32 */ 	 
+#endif /* UNICODE_SUPPORT */
 	if (encstr)
 	{
 		self->client_encoding = encstr;
@@ -385,7 +446,7 @@ CC_lookup_characterset(ConnectionClass *self)
 		if (stricmp(pg_CS_name(self->ccsc), encstr))
 		{
 			qlog(" Client encoding = '%s' and %s\n", self->client_encoding, pg_CS_name(self->ccsc));
-			CC_set_error(self, CONN_VALUE_OUT_OF_RANGE, "client encoding mismatch"); 
+			CC_set_error(self, CONN_VALUE_OUT_OF_RANGE, "client encoding mismatch");
 		}
 	}
 	else
@@ -406,15 +467,15 @@ int encoded_nextchar(encoded_str *encstr)
 {
 	int	chr;
 
-	chr = encstr->encstr[++encstr->pos]; 
+	chr = encstr->encstr[++encstr->pos];
 	encstr->ccst = pg_CS_stat(encstr->ccst, (unsigned int) chr, encstr->ccsc);
-	return chr; 
+	return chr;
 }
 int encoded_byte_check(encoded_str *encstr, int abspos)
 {
 	int	chr;
 
-	chr = encstr->encstr[encstr->pos = abspos]; 
+	chr = encstr->encstr[encstr->pos = abspos];
 	encstr->ccst = pg_CS_stat(encstr->ccst, (unsigned int) chr, encstr->ccsc);
-	return chr; 
+	return chr;
 }
