@@ -124,7 +124,7 @@ SQLColumns(HSTMT StatementHandle,
 		ret = PGAPI_Columns(StatementHandle, ctName, NameLength1,
 				scName, NameLength2, tbName, NameLength3,
 				clName, NameLength4, flag);
-	if (SQL_SUCCESS == ret && 0 == QR_get_num_total_tuples(SC_get_Result(stmt))) 
+	if (SQL_SUCCESS == ret && 0 == QR_get_num_total_tuples(SC_get_Result(stmt)))
 	{
 		BOOL	ifallupper = TRUE, reexec = FALSE;
 		char *newCt = NULL, *newSc = NULL, *newTb = NULL, *newCl = NULL;
@@ -132,22 +132,22 @@ SQLColumns(HSTMT StatementHandle,
 
 		if (SC_is_lower_case(stmt, conn)) /* case-insensitive identifier */
 			ifallupper = FALSE;
-		if (newCt = make_lstring_ifneeded(conn, CatalogName, NameLength1, ifallupper))
+		if ((newCt = make_lstring_ifneeded(conn, CatalogName, NameLength1, ifallupper)))
 		{
 			ctName = newCt;
 			reexec = TRUE;
 		}
-		if (newSc = make_lstring_ifneeded(conn, SchemaName, NameLength2, ifallupper))
+		if ((newSc = make_lstring_ifneeded(conn, SchemaName, NameLength2, ifallupper)))
 		{
 			scName = newSc;
 			reexec = TRUE;
-		}	
-		if (newTb = make_lstring_ifneeded(conn, TableName, NameLength3, ifallupper))
+		}
+		if ((newTb = make_lstring_ifneeded(conn, TableName, NameLength3, ifallupper)))
 		{
 			tbName = newTb;
 			reexec = TRUE;
 		}
-		if (newCl = make_lstring_ifneeded(conn, ColumnName, NameLength4, ifallupper))
+		if ((newCl = make_lstring_ifneeded(conn, ColumnName, NameLength4, ifallupper)))
 		{
 			clName = newCl;
 			reexec = TRUE;
@@ -594,7 +594,7 @@ SQLSpecialColumns(HSTMT StatementHandle,
 		ret = PGAPI_SpecialColumns(StatementHandle, IdentifierType, ctName,
 			NameLength1, scName, NameLength2, tbName, NameLength3,
 							Scope, Nullable);
-	if (SQL_SUCCESS == ret && 0 == QR_get_num_total_tuples(SC_get_Result(stmt))) 
+	if (SQL_SUCCESS == ret && 0 == QR_get_num_total_tuples(SC_get_Result(stmt)))
 	{
 		BOOL	ifallupper = TRUE, reexec = FALSE;
 		char *newCt =NULL, *newSc = NULL, *newTb = NULL;
@@ -602,17 +602,17 @@ SQLSpecialColumns(HSTMT StatementHandle,
 
 		if (SC_is_lower_case(stmt, conn)) /* case-insensitive identifier */
 			ifallupper = FALSE;
-		if (newCt = make_lstring_ifneeded(conn, CatalogName, NameLength1, ifallupper))
+		if ((newCt = make_lstring_ifneeded(conn, CatalogName, NameLength1, ifallupper)))
 		{
 			ctName = newCt;
 			reexec = TRUE;
 		}
-		if (newSc = make_lstring_ifneeded(conn, SchemaName, NameLength2, ifallupper))
+		if ((newSc = make_lstring_ifneeded(conn, SchemaName, NameLength2, ifallupper)))
 		{
 			scName = newSc;
 			reexec = TRUE;
 		}
-		if (newTb = make_lstring_ifneeded(conn, TableName, NameLength3, ifallupper))
+		if ((newTb = make_lstring_ifneeded(conn, TableName, NameLength3, ifallupper)))
 		{
 			tbName = newTb;
 			reexec = TRUE;
@@ -655,7 +655,7 @@ SQLStatistics(HSTMT StatementHandle,
 		ret = PGAPI_Statistics(StatementHandle, ctName, NameLength1,
 				 scName, NameLength2, tbName, NameLength3,
 				 Unique, Reserved);
-	if (SQL_SUCCESS == ret && 0 == QR_get_num_total_tuples(SC_get_Result(stmt))) 
+	if (SQL_SUCCESS == ret && 0 == QR_get_num_total_tuples(SC_get_Result(stmt)))
 	{
 		BOOL	ifallupper = TRUE, reexec = FALSE;
 		char *newCt =NULL, *newSc = NULL, *newTb = NULL;
@@ -663,17 +663,17 @@ SQLStatistics(HSTMT StatementHandle,
 
 		if (SC_is_lower_case(stmt, conn)) /* case-insensitive identifier */
 			ifallupper = FALSE;
-		if (newCt = make_lstring_ifneeded(conn, CatalogName, NameLength1, ifallupper))
+		if ((newCt = make_lstring_ifneeded(conn, CatalogName, NameLength1, ifallupper)))
 		{
 			ctName = newCt;
 			reexec = TRUE;
 		}
-		if (newSc = make_lstring_ifneeded(conn, SchemaName, NameLength2, ifallupper))
+		if ((newSc = make_lstring_ifneeded(conn, SchemaName, NameLength2, ifallupper)))
 		{
 			scName = newSc;
 			reexec = TRUE;
 		}
-		if (newTb = make_lstring_ifneeded(conn, TableName, NameLength3, ifallupper))
+		if ((newTb = make_lstring_ifneeded(conn, TableName, NameLength3, ifallupper)))
 		{
 			tbName = newTb;
 			reexec = TRUE;
@@ -689,7 +689,7 @@ SQLStatistics(HSTMT StatementHandle,
 				free(newSc);
 			if (newTb)
 				free(newTb);
-		}	
+		}
 	}
 	LEAVE_STMT_CS(stmt);
 	return ret;
@@ -716,7 +716,7 @@ SQLTables(HSTMT StatementHandle,
 		ret = PGAPI_Tables(StatementHandle, ctName, NameLength1,
 				scName, NameLength2, tbName, NameLength3,
 						TableType, NameLength4);
-	if (SQL_SUCCESS == ret && 0 == QR_get_num_total_tuples(SC_get_Result(stmt))) 
+	if (SQL_SUCCESS == ret && 0 == QR_get_num_total_tuples(SC_get_Result(stmt)))
 	{
 		BOOL	ifallupper = TRUE, reexec = FALSE;
 		char *newCt =NULL, *newSc = NULL, *newTb = NULL;
@@ -724,17 +724,17 @@ SQLTables(HSTMT StatementHandle,
 
 		if (SC_is_lower_case(stmt, conn)) /* case-insensitive identifier */
 			ifallupper = FALSE;
-		if (newCt = make_lstring_ifneeded(conn, CatalogName, NameLength1, ifallupper))
+		if ((newCt = make_lstring_ifneeded(conn, CatalogName, NameLength1, ifallupper)))
 		{
 			ctName = newCt;
 			reexec = TRUE;
 		}
-		if (newSc = make_lstring_ifneeded(conn, SchemaName, NameLength2, ifallupper))
+		if ((newSc = make_lstring_ifneeded(conn, SchemaName, NameLength2, ifallupper)))
 		{
 			scName = newSc;
 			reexec = TRUE;
 		}
-		if (newTb = make_lstring_ifneeded(conn, TableName, NameLength3, ifallupper))
+		if ((newTb = make_lstring_ifneeded(conn, TableName, NameLength3, ifallupper)))
 		{
 			tbName = newTb;
 			reexec = TRUE;
@@ -783,7 +783,7 @@ SQLColumnPrivileges(
 		ret = PGAPI_ColumnPrivileges(hstmt, ctName, cbCatalogName,
 				scName, cbSchemaName, tbName, cbTableName,
 						clName, cbColumnName);
-	if (SQL_SUCCESS == ret && 0 == QR_get_num_total_tuples(SC_get_Result(stmt))) 
+	if (SQL_SUCCESS == ret && 0 == QR_get_num_total_tuples(SC_get_Result(stmt)))
 	{
 		BOOL	ifallupper = TRUE, reexec = FALSE;
 		char *newCt = NULL, *newSc = NULL, *newTb = NULL, *newCl = NULL;
@@ -791,22 +791,22 @@ SQLColumnPrivileges(
 
 		if (SC_is_lower_case(stmt, conn)) /* case-insensitive identifier */
 			ifallupper = FALSE;
-		if (newCt = make_lstring_ifneeded(conn, szCatalogName, cbCatalogName, ifallupper))
+		if ((newCt = make_lstring_ifneeded(conn, szCatalogName, cbCatalogName, ifallupper)))
 		{
 			ctName = newCt;
 			reexec = TRUE;
 		}
-		if (newSc = make_lstring_ifneeded(conn, szSchemaName, cbSchemaName, ifallupper))
+		if ((newSc = make_lstring_ifneeded(conn, szSchemaName, cbSchemaName, ifallupper)))
 		{
 			scName = newSc;
 			reexec = TRUE;
 		}
-		if (newTb = make_lstring_ifneeded(conn, szTableName, cbTableName, ifallupper))
+		if ((newTb = make_lstring_ifneeded(conn, szTableName, cbTableName, ifallupper)))
 		{
 			tbName = newTb;
 			reexec = TRUE;
 		}
-		if (newCl = make_lstring_ifneeded(conn, szColumnName, cbColumnName, ifallupper))
+		if ((newCl = make_lstring_ifneeded(conn, szColumnName, cbColumnName, ifallupper)))
 		{
 			clName = newCl;
 			reexec = TRUE;
@@ -904,7 +904,7 @@ SQLForeignKeys(
 			pkscName, cbPkSchemaName, pktbName, cbPkTableName,
 			fkctName, cbFkCatalogName, fkscName, cbFkSchemaName,
 			fktbName, cbFkTableName);
-	if (SQL_SUCCESS == ret && 0 == QR_get_num_total_tuples(SC_get_Result(stmt))) 
+	if (SQL_SUCCESS == ret && 0 == QR_get_num_total_tuples(SC_get_Result(stmt)))
 	{
 		BOOL	ifallupper = TRUE, reexec = FALSE;
 		char *newPkct = NULL, *newPksc = NULL, *newPktb = NULL,
@@ -913,32 +913,32 @@ SQLForeignKeys(
 
 		if (SC_is_lower_case(stmt, conn)) /* case-insensitive identifier */
 			ifallupper = FALSE;
-		if (newPkct = make_lstring_ifneeded(conn, szPkCatalogName, cbPkCatalogName, ifallupper))
+		if ((newPkct = make_lstring_ifneeded(conn, szPkCatalogName, cbPkCatalogName, ifallupper)))
 		{
 			pkctName = newPkct;
 			reexec = TRUE;
 		}
-		if (newPksc = make_lstring_ifneeded(conn, szPkSchemaName, cbPkSchemaName, ifallupper))
+		if ((newPksc = make_lstring_ifneeded(conn, szPkSchemaName, cbPkSchemaName, ifallupper)))
 		{
 			pkscName = newPksc;
 			reexec = TRUE;
 		}
-		if (newPktb = make_lstring_ifneeded(conn, szPkTableName, cbPkTableName, ifallupper))
+		if ((newPktb = make_lstring_ifneeded(conn, szPkTableName, cbPkTableName, ifallupper)))
 		{
 			pktbName = newPktb;
 			reexec = TRUE;
 		}
-		if (newFkct = make_lstring_ifneeded(conn, szFkCatalogName, cbFkCatalogName, ifallupper))
+		if ((newFkct = make_lstring_ifneeded(conn, szFkCatalogName, cbFkCatalogName, ifallupper)))
 		{
 			fkctName = newFkct;
 			reexec = TRUE;
 		}
-		if (newFksc = make_lstring_ifneeded(conn, szFkSchemaName, cbFkSchemaName, ifallupper))
+		if ((newFksc = make_lstring_ifneeded(conn, szFkSchemaName, cbFkSchemaName, ifallupper)))
 		{
 			fkscName = newFksc;
 			reexec = TRUE;
 		}
-		if (newFktb = make_lstring_ifneeded(conn, szFkTableName, cbFkTableName, ifallupper))
+		if ((newFktb = make_lstring_ifneeded(conn, szFkTableName, cbFkTableName, ifallupper)))
 		{
 			fktbName = newFktb;
 			reexec = TRUE;
@@ -1059,7 +1059,7 @@ SQLPrimaryKeys(
 	else
 		ret = PGAPI_PrimaryKeys(hstmt, ctName, cbCatalogName,
 			scName, cbSchemaName, tbName, cbTableName);
-	if (SQL_SUCCESS == ret && 0 == QR_get_num_total_tuples(SC_get_Result(stmt))) 
+	if (SQL_SUCCESS == ret && 0 == QR_get_num_total_tuples(SC_get_Result(stmt)))
 	{
 		BOOL	ifallupper = TRUE, reexec = FALSE;
 		char *newCt = NULL, *newSc = NULL, *newTb = NULL;
@@ -1067,17 +1067,17 @@ SQLPrimaryKeys(
 
 		if (SC_is_lower_case(stmt, conn)) /* case-insensitive identifier */
 			ifallupper = FALSE;
-		if (newCt = make_lstring_ifneeded(conn, szCatalogName, cbCatalogName, ifallupper))
+		if ((newCt = make_lstring_ifneeded(conn, szCatalogName, cbCatalogName, ifallupper)))
 		{
 			ctName = newCt;
 			reexec = TRUE;
 		}
-		if (newSc = make_lstring_ifneeded(conn, szSchemaName, cbSchemaName, ifallupper))
+		if ((newSc = make_lstring_ifneeded(conn, szSchemaName, cbSchemaName, ifallupper)))
 		{
 			scName = newSc;
 			reexec = TRUE;
 		}
-		if (newTb = make_lstring_ifneeded(conn, szTableName, cbTableName, ifallupper))
+		if ((newTb = make_lstring_ifneeded(conn, szTableName, cbTableName, ifallupper)))
 		{
 			tbName = newTb;
 			reexec = TRUE;
@@ -1125,7 +1125,7 @@ SQLProcedureColumns(
 		ret = PGAPI_ProcedureColumns(hstmt, ctName, cbCatalogName,
 				scName, cbSchemaName, prName, cbProcName,
 					clName, cbColumnName);
-	if (SQL_SUCCESS == ret && 0 == QR_get_num_total_tuples(SC_get_Result(stmt))) 
+	if (SQL_SUCCESS == ret && 0 == QR_get_num_total_tuples(SC_get_Result(stmt)))
 	{
 		BOOL	ifallupper = TRUE, reexec = FALSE;
 		char *newCt = NULL, *newSc = NULL, *newPr = NULL, *newCl = NULL;
@@ -1133,22 +1133,22 @@ SQLProcedureColumns(
 
 		if (SC_is_lower_case(stmt, conn)) /* case-insensitive identifier */
 			ifallupper = FALSE;
-		if (newCt = make_lstring_ifneeded(conn, szCatalogName, cbCatalogName, ifallupper))
+		if ((newCt = make_lstring_ifneeded(conn, szCatalogName, cbCatalogName, ifallupper)))
 		{
 			ctName = newCt;
 			reexec = TRUE;
 		}
-		if (newSc = make_lstring_ifneeded(conn, szSchemaName, cbSchemaName, ifallupper))
+		if ((newSc = make_lstring_ifneeded(conn, szSchemaName, cbSchemaName, ifallupper)))
 		{
 			scName = newSc;
 			reexec = TRUE;
 		}
-		if (newPr = make_lstring_ifneeded(conn, szProcName, cbProcName, ifallupper))
+		if ((newPr = make_lstring_ifneeded(conn, szProcName, cbProcName, ifallupper)))
 		{
 			prName = newPr;
 			reexec = TRUE;
 		}
-		if (newCl = make_lstring_ifneeded(conn, szColumnName, cbColumnName, ifallupper))
+		if ((newCl = make_lstring_ifneeded(conn, szColumnName, cbColumnName, ifallupper)))
 		{
 			clName = newCl;
 			reexec = TRUE;
@@ -1196,7 +1196,7 @@ SQLProcedures(
 	else
 		ret = PGAPI_Procedures(hstmt, ctName, cbCatalogName,
 					 scName, cbSchemaName, prName, cbProcName);
-	if (SQL_SUCCESS == ret && 0 == QR_get_num_total_tuples(SC_get_Result(stmt))) 
+	if (SQL_SUCCESS == ret && 0 == QR_get_num_total_tuples(SC_get_Result(stmt)))
 	{
 		BOOL	ifallupper = TRUE, reexec = FALSE;
 		char *newCt = NULL, *newSc = NULL, *newPr = NULL;
@@ -1204,17 +1204,17 @@ SQLProcedures(
 
 		if (SC_is_lower_case(stmt, conn)) /* case-insensitive identifier */
 			ifallupper = FALSE;
-		if (newCt = make_lstring_ifneeded(conn, szCatalogName, cbCatalogName, ifallupper))
+		if ((newCt = make_lstring_ifneeded(conn, szCatalogName, cbCatalogName, ifallupper)))
 		{
 			ctName = newCt;
 			reexec = TRUE;
 		}
-		if (newSc = make_lstring_ifneeded(conn, szSchemaName, cbSchemaName, ifallupper))
+		if ((newSc = make_lstring_ifneeded(conn, szSchemaName, cbSchemaName, ifallupper)))
 		{
 			scName = newSc;
 			reexec = TRUE;
 		}
-		if (newPr = make_lstring_ifneeded(conn, szProcName, cbProcName, ifallupper))
+		if ((newPr = make_lstring_ifneeded(conn, szProcName, cbProcName, ifallupper)))
 		{
 			prName = newPr;
 			reexec = TRUE;
@@ -1277,7 +1277,7 @@ SQLTablePrivileges(
 	else
 		ret = PGAPI_TablePrivileges(hstmt, ctName, cbCatalogName,
 			scName, cbSchemaName, tbName, cbTableName, 0);
-	if (SQL_SUCCESS == ret && 0 == QR_get_num_total_tuples(SC_get_Result(stmt))) 
+	if (SQL_SUCCESS == ret && 0 == QR_get_num_total_tuples(SC_get_Result(stmt)))
 	{
 		BOOL	ifallupper = TRUE, reexec = FALSE;
 		char *newCt = NULL, *newSc = NULL, *newTb = NULL;
@@ -1285,17 +1285,17 @@ SQLTablePrivileges(
 
 		if (SC_is_lower_case(stmt, conn)) /* case-insensitive identifier */
 			ifallupper = FALSE;
-		if (newCt = make_lstring_ifneeded(conn, szCatalogName, cbCatalogName, ifallupper))
+		if ((newCt = make_lstring_ifneeded(conn, szCatalogName, cbCatalogName, ifallupper)))
 		{
 			ctName = newCt;
 			reexec = TRUE;
 		}
-		if (newSc = make_lstring_ifneeded(conn, szSchemaName, cbSchemaName, ifallupper))
+		if ((newSc = make_lstring_ifneeded(conn, szSchemaName, cbSchemaName, ifallupper)))
 		{
 			scName = newSc;
 			reexec = TRUE;
 		}
-		if (newTb = make_lstring_ifneeded(conn, szTableName, cbTableName, ifallupper))
+		if ((newTb = make_lstring_ifneeded(conn, szTableName, cbTableName, ifallupper)))
 		{
 			tbName = newTb;
 			reexec = TRUE;
