@@ -13,7 +13,6 @@
  */
 
 #include "statement.h"
-
 #include "bind.h"
 #include "connection.h"
 #include "qresult.h"
@@ -168,6 +167,8 @@ PGAPI_FreeStmt(HSTMT hstmt,
 			/* Free any cursors and discard any result info */
 			if (res = SC_get_Result(stmt), res)
 			{
+				if(SC_is_fetchcursor(stmt))
+					SC_set_handle(stmt,res);
 				QR_Destructor(res);
 				SC_set_Result(stmt,  NULL);
 			}
@@ -205,6 +206,19 @@ PGAPI_FreeStmt(HSTMT hstmt,
 }
 
 
+/*
+ * For Declare/Fetch, setting the parameters to close the cursor.
+ */
+void 
+SC_set_handle(StatementClass *self,QResultClass *res)
+{
+	res->conn = self->hdbc;
+	if(!res->cursor)
+		res->cursor = malloc(sizeof(self->cursor_name));
+	strcpy(res->cursor,self->cursor_name);
+}
+
+
 /*
  * StatementClass implementation
  */
@@ -235,7 +249,7 @@ SC_Constructor(void)
 		rv->phstmt = NULL;
 		rv->result = NULL;
 		rv->curres = NULL;
-		rv->manual_result = FALSE;
+		rv->manual_result = TRUE;
 		rv->prepare = FALSE;
 		rv->prepared = FALSE;
 		rv->status = STMT_ALLOCATED;
@@ -246,6 +260,7 @@ SC_Constructor(void)
 		rv->__error_message = NULL;
 		rv->__error_number = 0;
 		rv->errormsg_created = FALSE;
+		rv->__sqlstate[0] = '\0';
 
 		rv->statement = NULL;
 		rv->stmt_with_params = NULL;
@@ -328,6 +343,7 @@ SC_Destructor(StatementClass *self)
 	}
 
 	SC_initialize_stmts(self, TRUE);
+    SC_free_params(self, STMT_FREE_PARAMS_ALL);
 
         /* Free the parsed table information */
 	if (self->ti)
@@ -433,7 +449,7 @@ SC_set_prepared(StatementClass *stmt, BOOL prepared)
 		{
 			char	plannm[32];
 
-			sprintf(plannm, "_PLAN%0x", stmt);
+			sprintf(plannm, "_PLAN%p", stmt);
 			if (CC_is_in_error_trans(conn))
 			{
 				CC_mark_a_plan_to_discard(conn, plannm);
@@ -607,6 +623,8 @@ SC_recycle_statement(StatementClass *self)
 	/* Free any cursors */
 	if (res = SC_get_Result(self), res)
 	{
+		if(SC_is_fetchcursor(self))
+			SC_set_handle(self,res);
 		QR_Destructor(res);
 		SC_set_Result(self, NULL);
 	}
@@ -616,8 +634,7 @@ SC_recycle_statement(StatementClass *self)
 	 * Reset only parameters that have anything to do with results
 	 */
 	self->status = STMT_READY;
-	self->manual_result = FALSE;	/* very important */
-
+	self->manual_result = TRUE;		/* very important */
 	self->currTuple = -1;
 	self->rowset_start = -1;
 	SC_set_current_col(self, -1);
@@ -764,20 +781,14 @@ SC_create_errormsg(const StatementClass *self)
 	}
 	if (conn)
 	{
-		SocketClass *sock = conn->sock;
-
 		if (!detailmsg && CC_get_errormsg(conn) && (CC_get_errormsg(conn))[0] != '\0')
 		{
 			pos = strlen(msg);
 			sprintf(&msg[pos], ";\n%s", CC_get_errormsg(conn));
 		}
 
-		if (sock && sock->errormsg && sock->errormsg[0] != '\0')
-		{
-			pos = strlen(msg);
-			sprintf(&msg[pos], ";\n%s", sock->errormsg);
-		}
 	}
+
 	return msg[0] ? strdup(msg) : NULL;
 }
 
@@ -849,6 +860,21 @@ SC_get_error(StatementClass *self, int *number, char **message)
 	return rv;
 }
 
+void
+SC_set_sqlstate(StatementClass *self, const char *sqlstate)
+{
+    if (sqlstate)
+        snprintf(self->__sqlstate, SQLSTATE_LENGTH, "%s", sqlstate);
+    else
+        self->__sqlstate[0] = '\0';
+}
+
+char *
+SC_get_sqlstate(StatementClass *self)
+{
+    return self->__sqlstate;
+}
+
 
 time_t
 SC_get_time(StatementClass *stmt)
@@ -885,6 +911,10 @@ SC_fetch(StatementClass *self)
 				lf;
 	Oid			type;
 	char	   *value;
+	char		fetch[128];
+
+	QueryInfo	qi;
+	UDWORD 		qflag = 0;
 	ColumnInfoClass *coli;
 	BindInfoClass	*bookmark;
 
@@ -892,21 +922,61 @@ SC_fetch(StatementClass *self)
 	ConnInfo   *ci = &(SC_get_conn(self)->connInfo);
 
 	self->last_fetch_count = self->last_fetch_count_include_ommitted = 0;
-	coli = QR_get_fields(res);	/* the column info */
 
+	/* Issue the fetch query here in case of declare fetch for subsequent rows */
+	if (SC_is_fetchcursor(self) && ((self->currTuple % ci->drivers.fetch_max) >= QR_get_num_total_tuples(res) - 1))
+	{
+		qi.result_in = NULL;
+		qi.cursor = self->cursor_name;
+		qi.row_size = ci->drivers.fetch_max;
+		sprintf(fetch, "fetch %d in %s",ci->drivers.fetch_max ,self->cursor_name);
+
+        /* Cleanup the QR. We need to kill off the cursor first, or this willcrash */
+
+        if (self->result->cursor)
+        {
+            free(self->result->cursor);
+            self->result->cursor = NULL;
+        }
+
+        if (self->result)
+        {
+            QR_Destructor(self->result);
+            self->result = NULL;
+        }
+
+        /* Finished cleanup */
+
+        res = CC_send_query(self->hdbc, fetch, &qi, qflag);
+		SC_set_Result(self,res);
+	}
+
+    coli = QR_get_fields(res);	/* the column info */
 	mylog("manual_result = %d, use_declarefetch = %d\n", self->manual_result, ci->drivers.use_declarefetch);
 
-	if (self->manual_result || !SC_is_fetchcursor(self))
+	if (self->manual_result)
 	{
-		if (self->currTuple >= QR_get_num_total_tuples(res) - 1 ||
-			(self->options.maxRows > 0 && self->currTuple == self->options.maxRows - 1))
+		if(!SC_is_fetchcursor(self))
 		{
-			/*
-			 * if at the end of the tuples, return "no data found" and set
-			 * the cursor past the end of the result set
-			 */
-			self->currTuple = QR_get_num_total_tuples(res);
-			return SQL_NO_DATA_FOUND;
+			if (self->currTuple >= QR_get_num_total_tuples(res) - 1 ||
+				(self->options.maxRows > 0 && self->currTuple == self->options.maxRows - 1))
+			{
+				/*
+				 * if at the end of the tuples, return "no data found" and set
+				 * the cursor past the end of the result set
+				 */
+				self->currTuple = QR_get_num_total_tuples(res);
+				return SQL_NO_DATA_FOUND;
+			}
+		}
+		else
+		{
+			if ((((self->currTuple + 1) % ci->drivers.fetch_max) >= QR_get_num_total_tuples(res)) &&
+				QR_get_num_total_tuples(res) < ci->drivers.fetch_max)
+			{
+				self->currTuple = QR_get_num_total_tuples(res);
+				return SQL_NO_DATA_FOUND;
+			}
 		}
 
 		mylog("**** SC_fetch: manual_result\n");
@@ -931,6 +1001,7 @@ SC_fetch(StatementClass *self)
 			return SQL_ERROR;
 		}
 	}
+
 #ifdef	DRIVER_CURSOR_IMPLEMENT
 	if (res->haskeyset)
 	{
@@ -961,7 +1032,7 @@ SC_fetch(StatementClass *self)
 		char		buf[32];
 		UInt4	offset = opts->row_offset_ptr ? *opts->row_offset_ptr : 0;
 
-		sprintf(buf, "%ld", SC_get_bookmark(self));
+		sprintf(buf, "%ld", (long int) SC_get_bookmark(self));
 		SC_set_current_col(self, -1);
 		result = copy_and_convert_field(self, 0, buf, SQL_C_ULONG,
 						bookmark->buffer + offset, 0,
@@ -991,7 +1062,7 @@ SC_fetch(StatementClass *self)
 
 			if (self->manual_result)
 			{
-				value = QR_get_value_manual(res, self->currTuple, lf);
+				value = QR_get_value_manual(res, (self->currTuple >= ci->drivers.fetch_max) ? (self->currTuple % ci->drivers.fetch_max) : self->currTuple, lf);
 				mylog("manual_result\n");
 			}
 			else if (SC_is_fetchcursor(self))
@@ -1197,6 +1268,12 @@ SC_execute(StatementClass *self)
 		else
 			SC_set_errornumber(self, was_nonfatal ? STMT_INFO_ONLY : STMT_ERROR_TAKEN_FROM_BACKEND);
 
+		if (QR_command_fatal(res) && PQstatus(conn->pgconn) == CONNECTION_BAD)
+		    SC_set_errornumber(self, STMT_BAD_ERROR);
+
+		if (SC_get_errornumber(self) == STMT_ERROR_TAKEN_FROM_BACKEND)
+			SC_set_sqlstate(self, CC_get_sqlstate(conn));
+
 		/* set cursor before the first tuple in the list */
 		self->currTuple = -1;
 		SC_set_current_col(self, -1);
@@ -1234,8 +1311,8 @@ SC_execute(StatementClass *self)
 	else
 	{
 		/* Bad Error -- The error message will be in the Connection */
-		if (!conn->sock)
-			SC_set_error(self, STMT_BAD_ERROR, CC_get_errormsg(conn));
+		if (!conn->pgconn)
+		SC_set_error(self, STMT_BAD_ERROR, CC_get_errormsg(conn));
 		else if (self->statement_type == STMT_TYPE_CREATE)
 		{
 			SC_set_error(self, STMT_CREATE_TABLE_ERROR, "Error creating the table");
